@@ -36,7 +36,7 @@ class Variables:
             x = re.search('<(.+?)>', v[1], re.M | re.I)
             if x:
                 x = self.get(x.group(1))
-                if str(x) not in ['y', 'yes', 't', 'true', '1']:
+                if str(x) not in ['y', 'yes', 't', 'true', '1', True, 1]:
                     return None
                 var = v[0].strip()
 
@@ -108,6 +108,8 @@ class Solution:
 
         if (not self.board_component) and (not self.solution_component.hw_info.cpu_name) and (not self.solution_component.hw_info.ld_script):
             for name in self.solution_component.depends:
+                if type(name) == dict:
+                    name = list(name.keys())[0]
                 component = self.components.get(name)
                 if component:
                     if component.type == 'board':
@@ -170,12 +172,24 @@ class Solution:
             self.variables.set(gen_arch_defs(arch), 1)
             self.variables.set(gen_cpu_defs(cpu), 1)
 
-        for component in self.components:
-            # defines
+        def add_defines(component):
             for k, v in component.defconfig.items():
                 self.variables.set(k, v)
                 self.defines[k] = v
                 self.org_defines[k] = v
+        # copy defines
+        for component in self.components:
+            if component.type == 'common':
+                add_defines(component)
+        for component in self.components:
+            if component.type == 'chip':
+                add_defines(component)
+        for component in self.components:
+            if component.type == 'board':
+                add_defines(component)
+        for component in self.components:
+            if component.type == 'solution':
+                add_defines(component)
 
         solution_hw_info = HardwareInfo({})
         for component in [self.chip_component, self.board_component, self.solution_component]:
@@ -373,7 +387,7 @@ def riscv_cpu_id(cpu):
         return 'rv32fd_32gpr'
     elif a == 'c906':
         return 'rv64_32gpr'
-    elif a == 'c906fd' or a == 'c906v' or a == 'c910' or a == 'c910v':
+    elif a == 'c906fd' or a == 'c906fdv' or a == 'c906v' or a == 'c910' or a == 'c910v':
         return 'rv64fd_32gpr'
     else:
         put_string("%s not support yet." % a)
