@@ -20,6 +20,6 @@ Add your RSA public key into repo.
 
     def Execute(self, opt, args):
         conf = Configure()
-        repo = RepoGitee(conf.gitee_token)
+        repo = RepoGitee(conf.gitee_token, conf.group)
         repo.add_public_key()
 
