@@ -27,8 +27,12 @@ Directory to component
             self.convert(dir_name)
 
     def convert(self, directory):
+        directory = os.path.abspath(directory)
+        if not os.path.exists(directory):
+            put_string("Directory:'%s' is not existed" % directory)
+            return
         if os.path.isfile(os.path.join(directory, 'package.yaml')):
-            print("Directory `%s` is already a component" % directory)
+            put_string("Directory:'%s' is already a component" % directory)
             return
         pack = Package()
         pack.name = os.path.basename(directory)
