@@ -21,8 +21,11 @@ Format component package.yaml file
 
     def Execute(self, opt, args):
         yoc = YoC()
-
+        name_list = yoc.get_name_list(yoc.components)
         count = len(args)
+        for name in args:
+            if name not in name_list:
+                put_string("There is no component:%s found." % name)
         for component in yoc.components:
             if count == 0 or component.name in args:
                 put_string("Formating package: %s." % component.name)
