@@ -88,3 +88,6 @@ Displays detailed usage information about a command.
 
         else:
             self._PrintCommandHelp(self)
+
+        put_string("\r\nGeneral Options:")
+        put_string("-V, --version   Show version and exit.")
