@@ -43,6 +43,10 @@ List all projects; pass '.' to list the project for the cwd.
                      dest='sdk', action='store_true',
                      help='list all sdk component')
 
+        p.add_option('-p', '--sdk_chip',
+                     dest='sdk_chip', action='store_true',
+                     help='list all sdk_chip component')
+
         p.add_option('-d', '--depend',
                      dest='depend', action='store_true',
                      help='list component dependencies')
@@ -53,31 +57,33 @@ List all projects; pass '.' to list the project for the cwd.
         count = len(args)
 
         if opt.show_remote:
-            yoc.gitee_update()
-            group = yoc.occ_components
+            yoc.update(True)
+            components = yoc.occ_components
         else:
-            group = yoc.components
-            for c in group:
+            components = yoc.components
+            for c in components:
                 if count == 0 or c.name in args:
                     c.load_package()
         
-        if len(group) == 0:
+        if len(components) == 0:
             put_string("There is no component found!")
             exit(-1)
 
         nonexistent_cnt = 0
-        name_list = yoc.get_name_list(group)
+        name_list = yoc.get_name_list(components)
         for name in args:
             if name not in name_list:
                 put_string("Can't found component `%s`!" % name)
                 nonexistent_cnt+=1
 
-        show = opt.board or opt.chip or opt.common or opt.solution or opt.sdk
+        show = opt.board or opt.chip or opt.common or opt.solution or opt.sdk or opt.sdk_chip
         show_cnt = 0
-        for c in group:
+        for c in components:
             if count == 0 or c.name in args:
                 if show:
-                    if (opt.board and c.type == 'board') or (opt.chip and c.type == 'chip') or (opt.common and c.type == 'common') or (opt.solution and c.type == 'solution') or (opt.sdk and c.type == 'sdk'):
+                    if (opt.board and c.type == 'board') or (opt.chip and c.type == 'chip') \
+                        or (opt.common and c.type == 'common') or (opt.solution and c.type == 'solution') \
+                        or (opt.sdk and c.type == 'sdk') or (opt.sdk_chip and c.type == 'sdk_chip'):
                         self.show_depend(yoc, c, opt.depend)
                         show_cnt+=1
                 else:
@@ -96,5 +102,5 @@ List all projects; pass '.' to list the project for the cwd.
                 depend.show(8)
             depend_on = yoc.check_depend_on(component)
             if len(depend_on) > 0:
-                put_string("    depends on:")
+                put_string("    be depended(被依赖):")
                 depend_on.show(8)
