@@ -29,7 +29,7 @@ set branch protection
             return
         br = args[0]
         yoc = YoC()
-        repo = RepoGitee(yoc.conf.gitee_token)
+        repo = RepoGitee(yoc.conf.gitee_token, yoc.conf.group)
         for component in yoc.components:
             put_string("Start to set branch: %s protection for component:%s ." % (br, component.name))
             repo.set_branch_protection(component.name, br)
