@@ -24,8 +24,14 @@ Component rename <old_name> to <new_name>.
         if len(args) == 2:
             old_name = args[0]
             new_name = args[1]
+            if is_contain_chinese(new_name.encode('utf8').decode('utf8')) or not is_leagal_name(new_name):
+                put_string("New name: %s is not valid!" % new_name)
+                exit(-1)
             component = yoc.components.get(old_name)
             if component:
+                if os.getcwd() == component.path:
+                    put_string("Can't rename component in its own directory!")
+                    exit(-1)
                 dep_on = yoc.check_depend_on(component)
                 if component.rename(new_name):
                     for c in dep_on:
@@ -33,11 +39,13 @@ Component rename <old_name> to <new_name>.
                             if old_name in v:
                                 c.pack.depends.remove(v)
                         c.pack.depends.append({component.name: component.version})
-                        c.pack.save()
-                        put_string("component %s package.yaml is upgraded." % c.name)
-                    put_string("component `%s` -> `%s` success." % (old_name, new_name))
+                        c.pack.save(os.path.join(c.path, 'package.yaml'))
+                        put_string("Component %s's package.yaml is upgraded." % c.name)
+                    put_string("Component `%s` -> `%s` success." % (old_name, new_name))
                 else:
-                    put_string("component rename fail.")
+                    put_string("Component rename fail!")
             else:
-                put_string("component `%s` not found." % old_name)
+                put_string("Component `%s` not found!" % old_name)
+        else:
+            self.Usage()
 
