@@ -19,9 +19,9 @@ Search for components whose name or summary contains <query>
 """
 
     def _Options(self, p):
-        p.add_option('-u', '--upgrade',
-                     dest='upgrade', action='store_true',
-                     help='upgrade component from OCC')
+        p.add_option('-u', '--update',
+                     dest='update', action='store_true',
+                     help='update component from git or OCC')
 
     def Execute(self, opt, args):
         if len(args) != 1:
@@ -32,8 +32,8 @@ Search for components whose name or summary contains <query>
             exit(-1)
 
         yoc = YoC()
-        if opt.upgrade or yoc.occ_components == None:
-            yoc.gitee_update()
+        if opt.update or yoc.occ_components == None:
+            yoc.update(True)
 
         for component in yoc.occ_components:
             keys = [kword, kword.lower(), kword.upper()]
