@@ -9,31 +9,39 @@ from yoctools import *
 
 class Upload(Command):
     common = True
-    helpSummary = "Upload component to OCC"
+    helpSummary = "Upload components to git or OCC"
     helpUsage = """
 %prog [option] [<component>...]
 """
     helpDescription = """
-upload component to OCC
+Upload components to git or OCC
 """
 
     def _Options(self, p):
         p.add_option('-g', '--git',
-                     dest='update_git', action='store_true',
+                     dest='upload_gitee', action='store_true',
                      help='upload code to git repo')
         p.add_option('-o', '--occ',
-                     dest='update_occ', action='store_true',
+                     dest='upload_occ', action='store_true',
                      help='upload code to OCC')
-
+        p.add_option('-e', '--aone',
+                     dest='upload_aone', action='store', type='string',
+                     help='upload code to code.aone')
+        p.add_option('-p', '--prefix',
+                     dest='prefix', action='store', type='string',
+                     help="specify the component name's prefix")
+        p.add_option('-t', '--type',
+                     dest='type', action='store', type='string',
+                     help="specify the component type")
 
     def Execute(self, opt, args):
-        if not (opt.update_git or opt.update_occ):
+        if not (opt.upload_gitee or opt.upload_occ or opt.upload_aone):
             self.Usage()
             return
 
         yoc = YoC()
         count = len(args)
-        if opt.update_git:
+        if opt.upload_gitee:
             repo = RepoGitee(yoc.conf.gitee_token, yoc.conf.group)
             if repo:
                 if count == 0:
@@ -41,13 +49,12 @@ upload component to OCC
                 flag = False
                 for component in yoc.components:
                     if component.name in args or count == 0:
-                        if count > 0:
-                            flag = True
+                        flag = True
                         component.load_package()
                         ssh_url = repo.create_project(
                             component.name, component.json_dumps())
                         if ssh_url:
-                            put_string("Uploading %s, please wait..." % component.name)
+                            put_string("Uploading %s(%s), please wait..." % (component.name, component.version))
                             component.upload()
                             put_string("Upload %s finish." % component.name)
                         else:
@@ -57,7 +64,7 @@ upload component to OCC
             else:
                 put_string("Connect git repo error!")
 
-        if opt.update_occ:
+        elif opt.upload_occ:
             if count == 0:
                 put_string("Uploading all components, please wait...")
                 yoc.uploadall()
@@ -65,3 +72,21 @@ upload component to OCC
                 for name in args:
                     put_string("Start to upload component:%s to OCC." % name)
                     yoc.upload(name)
+        
+        elif opt.upload_aone:
+            if count == 0:
+                put_string("Uploading all components, please wait...")
+            flag = False
+            for component in yoc.components:
+                if (component.name in args) or count == 0:
+                    flag = True
+                    component.load_package()
+                    if opt.prefix and not component.name.startswith(opt.prefix):
+                        continue
+                    if opt.type and component.type != opt.type:
+                        continue
+                    put_string("Uploading %s(%s), please wait..." % (component.name, component.version))
+                    component.upload(opt.upload_aone)
+                    put_string("Upload %s finish." % component.name)
+            if not flag:
+                put_string("Can't find components:%s!" % str(args))
