@@ -10,12 +10,12 @@ from yoctools import *
 
 class Variable(Command):
     common = True
-    helpSummary = "Display variables for the current project"
+    helpSummary = "Display variables for the current solution"
     helpUsage = """
 %prog [option] [<variable>...]
 """
     helpDescription = """
-Display variables for the current project
+Display variables for the current solution
 """
     def _Options(self, p):
         p.add_option('-b', '--board',
@@ -25,6 +25,9 @@ Display variables for the current project
     def Execute(self, opt, args):
         yoc = YoC()
         solution = yoc.getSolution(opt.board_name)
+        if solution == None:
+            put_string("The current directory is not a solution!")
+            exit(0)
         if len(args) == 0:
             for k, v in solution.variables.items():
                 put_string("%-10s = %s" % (k, v))
