@@ -178,7 +178,7 @@ def wget(url, out_file):
 
         # 设置下载进度条
         f = sys.stdout
-        percent = recv_size / totalsize
+        percent = float(recv_size) / totalsize
         if percent > 1:
             percent = 1
         percent_str = " %.2f%%" % (percent * 100)
