@@ -12,6 +12,7 @@ import codecs
 
 from .tools import *
 from .component import *
+from .manifest import *
 from .occ import *
 from .log import logger
 from .solution import *
@@ -20,7 +21,6 @@ from .repo import *
 
 class Configure:
     def __init__(self):
-        self.yoc_version = ''
         self.lastUpdateTime = 0
         self.gitlab_token = ''
         self.github_token = ''
@@ -29,7 +29,8 @@ class Configure:
         self.username = ''
         self.password = ''
         self.occ_host = 'occ.t-head.cn'
-        self.repo = ''
+        self.repo = 'https://gitee.com/yocop/manifest.git'
+        self.branch = 'master'       # manifest.git的branch
         self.init = False
 
         self.yoc_path = os.getcwd()
@@ -50,20 +51,33 @@ class Configure:
             tmp_path = os.path.dirname(tmp_path)
 
         if self.repo:
-            if self.repo.startswith('http'):
-                self.group = self.repo.split('/')[-1]
-            elif self.repo.startswith('git@'):
-                self.group = self.repo.split(':')[-1]
+            if self.repo.endswith('.git'):
+                if self.repo.startswith('http'):    # like 'https://gitee.com/yocop/manifest.git'
+                    self.group = self.repo.split('/')[-2]
+                elif self.repo.startswith('git@'):  # like 'git@gitlab.alibaba-inc.com:yocopen/manifest.git'
+                    self.group = self.repo.split(':')[-1].split('/')[-2]
+                else:
+                    put_string('The repo is wrong!')
             else:
-                put_string('The repo is wrong!')
+                if self.repo.startswith('http'):    # like 'https://gitee.com/yocop'
+                    self.group = self.repo.split('/')[-1]
+                elif self.repo.startswith('git@'):  # like 'git@gitlab.alibaba-inc.com:yocopen'
+                    self.group = self.repo.split(':')[-1]
+                else:
+                    put_string('The repo is wrong!')
+    def load(self, yoc_file):
+        if os.path.isfile(yoc_file):
+            conf = yaml_load(yoc_file)
+            if conf:
+                for k, v in conf.items():
+                    self.__dict__[k] = v
 
     def save(self, yoc_file=None):
         if not yoc_file:
             yoc_file = os.path.join(self.yoc_path, '.yoc')
         with codecs.open(yoc_file, 'w', 'UTF-8') as f:
             for k, v in self.__dict__.items():
-                # if k not in ['yoc_path', 'init', 'repo', 'gitee_token'] and v:
-                if k not in ['yoc_path', 'init'] and v:
+                if k not in ['yoc_path', 'init', 'group', 'yoc_version'] and v:
                     f.write("{}: {}\n".format(k, v))
         self.init = True
 
@@ -121,10 +135,6 @@ class YoC:
         self.conf = Configure()
         self.yoc_path = self.conf.yoc_path
 
-        if not self.conf.yoc_version:
-            put_string("Please add yoc_version filed in .yoc file! e.g.\nyoc_version: v7.3.0")
-            exit(-1)
-
         try:
             compenent_db = os.path.join(self.yoc_path, '.components.db')
             with open(compenent_db, "rb") as f:
@@ -142,10 +152,6 @@ class YoC:
         package_yamls = self.conf.search_pacakge_yaml(
             ['boards', 'components', 'examples'], ['solutions'])
 
-        # filename = os.path.join(os.getcwd(), 'package.yaml')
-        # if os.path.isfile(filename):
-        #     package_yamls.append(filename)
-
         filename = os.path.join(os.getcwd(), 'package.yaml')
         if os.path.isfile(filename):
             pack = Package(filename)
@@ -162,6 +168,27 @@ class YoC:
                              (pack.name, pre_component.path, pack.path))
                 exit(0)
 
+    def clone_manifest(self, is_all=False):
+        manifest_path = os.path.join(self.yoc_path, ".repo")
+        if not os.path.exists(manifest_path):
+            os.mkdir(manifest_path)
+        repo_url = self.conf.repo
+        prj = GitRepo(manifest_path, repo_url)
+        if is_all:
+            prj.pull('master', None)
+        else:
+            prj.pull(self.conf.branch, None)
+
+    def manifest_yaml_parse(self, filename=None):
+        if not filename:
+            filename = os.path.join(self.yoc_path, ".repo/default.yaml")
+        if os.path.isfile(filename):
+            mani = Manifest(filename)
+            return mani
+        else:
+            put_string("Can't find %s" % filename)
+            put_string("Maybe there is no branch(%s) in %s" % (self.conf.branch, self.conf.repo))
+
     def get_name_list(self, group):
         name_list = []
         for c in group:
@@ -173,25 +200,28 @@ class YoC:
             component.load_package()
 
             for name in component.depends:
+                if type(name) == dict:
+                    name = list(name.keys())[0]
                 c = self.components.get(name)
                 if c:
-                    if c not in depends:
-                        depends.append(c)
+                    if c not in depend_cmpts:
+                        depend_cmpts.append(c)
                     if component not in c.depends_on:
                         c.depends_on.append(component)
                     _check_depend(c)
 
-        depends = ComponentGroup()
+        depend_cmpts = ComponentGroup()
 
         _check_depend(component)
-        return depends
+        return depend_cmpts
 
     def check_depend_on(self, component):
         depends_on = ComponentGroup()
         for c in self.components:
             c.load_package()
-            if component.name in c.depends:
-                depends_on.append(c)
+            for d in c.depends:
+                if component.name in d:
+                    depends_on.append(c)
         return depends_on
 
     def getSolution(self, board_name=None):
@@ -207,6 +237,8 @@ class YoC:
                 # 根据指定的board_name过滤其他的board组件
                 exclude_names = []
                 for name in component.depends:
+                    if type(name) == dict:
+                        name = list(name.keys())[0]
                     c = self.components.get(name)
                     if c:
                         c.load_package()
@@ -221,6 +253,22 @@ class YoC:
 
                 return solution
 
+    def check_cmpt_download(self, name, update=True, force=False):
+        if self.components.get(name) and not force:
+            put_string("Component `%s` have installed already! Please add -f option to install force!" % name)
+        else:
+            if update:
+                self.update()
+            if self.occ_components:
+                component = self.occ_components.get(name)
+                if component:
+                    return component
+                else:
+                    put_string("Can't find component %s." % name)
+            else:
+                put_string("There is no component found from server!")
+        return None
+
     def download_component(self, name, update=True, force=False):
         if self.components.get(name) and not force:
             put_string("Component `%s` have installed already! Please add -f option to install force!" % name)
@@ -243,12 +291,14 @@ class YoC:
         component = self.components.get(name)
         if component:
             if not component.depends_on:                     # 如果没有组件依赖它
-                for dep in component.depends:
-                    p = self.components.get(dep)
+                for n in component.depends:
+                    if type(n) == dict:
+                        n = list(n.keys())[0]
+                    p = self.components.get(n)
                     if p:
                         if name in p.depends_on:
                             del p.depends_on[name]
-                        self.remove_component(dep)
+                        self.remove_component(n)
 
                 shutil.rmtree(component.path)
                 self.components.remove(component)
@@ -259,49 +309,97 @@ class YoC:
                     logger.info('  ' + dep.name)
                 return False
 
+    def occ_login(self):
+        if self.occ == None:
+            self.occ = OCC(self.conf)
+        if not self.occ.login():
+            put_string("Login OCC failed. Please check your username and password.")
+            return False
+        return True
+
     def upload(self, name):
         component = self.components.get(name)
         if component:
             component.load_package()
-            if not os.path.isdir(os.path.join(component.path, '.git')):
-                if self.occ == None:
-                    self.occ = OCC(self.conf)
-                self.occ.login()
+            version = component.version
+            if version:
+                if not os.path.isdir(os.path.join(component.path, '.git')):
+                    if self.occ == None:
+                        self.occ = OCC(self.conf)
+                    self.occ.login()
+                    zip_file = component.zip(self.yoc_path)
+                    if self.occ.upload(version, component.type, zip_file) == 0:
+                        put_string("Component %s(%s) upload success!" % (component.name, version))
+                    else:
+                        put_string("Component %s(%s) upload failed!" % (component.name, version))
+                else:
+                    put_string("It is a git repo,abort to upload.")
+            else:
+                put_string("Component %s version is empty!" % (component.name))
+
+    def uploadall(self):
+        if self.occ == None:
+            self.occ = OCC(self.conf)
+        self.occ.login()
+        for component in self.components:
+            component.load_package()
+            version = component.version
+            if version:
                 zip_file = component.zip(self.yoc_path)
-
-                version = component.version
-                if self.occ.conf.yoc_version:
-                    version = self.occ.conf.yoc_version
-
                 if self.occ.upload(version, component.type, zip_file) == 0:
                     put_string("Component %s(%s) upload success!" % (component.name, version))
                 else:
                     put_string("Component %s(%s) upload failed!" % (component.name, version))
-                # self.save_version()
             else:
-                put_string("It is a git repo,abort to upload.")
+                put_string("Component %s version is empty!" % (component.name))
 
-    def uploadall(self):
-        if self.occ == None:
-            self.occ = self.occ = OCC(self.conf)
-        self.occ.login()
-        for component in self.components:
-            component.load_package()
-            zip_file = component.zip(self.yoc_path)
-            version = component.version
-            if self.occ.conf.yoc_version:
-                version = self.occ.conf.yoc_version
-
-            if self.occ.upload(version, component.type, zip_file) == 0:
-                put_string("Component %s(%s) upload success!" % (component.name, version))
+    def update(self, is_all=False):
+        def get_repo_url(remotes, cmp_ele):
+            if cmp_ele.remote.startswith('https://') \
+                or cmp_ele.remote.startswith('http://') \
+                or cmp_ele.remote.startswith('git@'):
+                return cmp_ele.remote
             else:
-                put_string("Component %s(%s) upload failed!" % (component.name, version))
+                for r in remotes:
+                    if cmp_ele.remote == r.name:
+                        repo_url = os.path.join(r.remote, '%s.git' % cmp_ele.name)
+                        return repo_url
+        def get_cmpt_path(name, type):
+            if type == 'board':
+                path = os.path.join('boards', name)
+            elif type == 'solution':
+                path = os.path.join('solutions', name)
+            else:
+                path = os.path.join('components', name)
+            return os.path.join(self.conf.yoc_path, path)
 
-    def update(self):
-        for component in self.components:
-            component.load_package()
-            component.download(self.yoc_path)
+        self.clone_manifest(is_all)
+        self.default_mani = self.manifest_yaml_parse()
+        if self.default_mani:
+            self.occ_components = ComponentGroup()
+            for p in self.default_mani.cmpt_list:
+                cmp = Component(self.conf)
+                cmp.name = p.name
+                cmp.type = p.type
+                cmp.description = p.desc
+                cmp.repo_url = get_repo_url(self.default_mani.remotes, p)
+                cmp.path = get_cmpt_path(cmp.name, cmp.type)
+                # print(cmp.name, cmp.type, cmp.repo_url, cmp.description, cmp.path)
+                self.occ_components.add(cmp)
+            with open(os.path.join(self.yoc_path, '.components.db'), "wb") as f:
+                pickle.dump(self.occ_components, f)
+                self.conf.save()
 
+    def update_version(self, depends=[]):
+        for component in self.occ_components:
+            for d in depends:
+                if type(d) == dict:
+                    name = list(d.keys())[0]
+                    if component.name == name:
+                        component.version = list(d.values())[0]
+                        # print("update %s version:%s" % (component.name, component.version))
+                        break
+            
     def gitee_update(self):
         self.occ_components = ComponentGroup()
         if not self.conf.gitee_token:
@@ -323,30 +421,21 @@ class YoC:
 
     def occ_update(self):
         if self.occ == None:
-            self.occ = self.occ = OCC(self.conf)
+            self.occ = OCC(self.conf)
+        put_string("Updating from OCC...Please wait.")
+        components, time = self.occ.yocComponentList('614193542956318720', self.conf.lastUpdateTime)
+        put_string("Update from OCC over.")
+        if components:
+            self.occ_components = components
+            self.conf.lastUpdateTime = time
+            for component in self.occ_components:
+                component.path = os.path.join(self.yoc_path, component.path)
 
-            components, time = self.occ.yocComponentList(
-                '614193542956318720', self.conf.lastUpdateTime)
-            if components:
-                self.occ_components = components
-                self.conf.lastUpdateTime = time
-                for component in self.occ_components:
-                    component.path = os.path.join(
-                        self.yoc_path, component.path)
-
-                with open(os.path.join(self.yoc_path, '.components.db'), "wb") as f:
-                    pickle.dump(self.occ_components, f)
-                    self.conf.save()
+            with open(os.path.join(self.yoc_path, '.components.db'), "wb") as f:
+                pickle.dump(self.occ_components, f)
+                self.conf.save()
 
     def list(self):
         for component in self.components:
             component.load_package()
             component.show()
-            # if component.depends:
-            #     put_string('  ', 'depends:')
-            #     for v in component.depends:
-            #         put_string('    -', v)
-            # if component.depends_on:
-            #     put_string('  ', 'depends_on:')
-            #     for p in component.depends_on:
-            #         put_string('    -', p.name)
